<?php         
namespace Concrete\Package\AbDisableCopy;

use Package;
use BlockType;
use Page;
use SinglePage;
use Events;
use Config;
use AssetList;
use Concrete\Core\Entity\Attribute\Key\PageKey;

/**
 * ab_disable_copy package for Concrete5
 * Copyright Copyright 2017-2018, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_disable_copy
 */
 
class Controller extends Package {

	protected $pkgHandle = 'ab_disable_copy';
	protected $appVersionRequired = '8.3.2';
	protected $pkgVersion = '1.0.0';
	protected $pkgAutoloaderMapCoreExtensions = true;
	
    public function getPackageDescription() 
	{
		return t('Disable page or site content copy functionality');
	}
	
	public function getPackageName() 
	{
		return t("Disable page or site content copy");
	}
	
	public function install() 
	{
		$pkg = parent::install();
		BlockType::installBlockType('ab_disable_copy', $pkg);
		$this->installAttributes($pkg);
		$this->installSinglePages($pkg);
    }
    
    public function uninstall()
    {
        $pkg = parent::uninstall();
        $this->uninstallAttributes();
        $config = $this->app->make('config');
        $config->save('concrete.permissions.disable_copy', false);
    }
    
    protected function installAttributes($pkg)
    {
        $service = $this->app->make('Concrete\Core\Attribute\Category\CategoryService');
        $categoryEntity = $service->getByHandle('collection');
        $category = $categoryEntity->getController();
		$key = $category->getByHandle('disable_copy');
        if (!is_object($key)) {
            $key = new PageKey();
            $key->setAttributeKeyHandle('disable_copy');
            $key->setAttributeKeyName('Disable page copy');
            $key = $category->add('boolean', $key, null, $pkg);
        }
    }

    protected function uninstallAttributes()
    {
        $service = $this->app->make('Concrete\Core\Attribute\Category\CategoryService');
        $categoryEntity = $service->getByHandle('collection');
        $category = $categoryEntity->getController();
		$key = $category->getByHandle('disable_copy');
        if (is_object($key)) {
            $key->delete();
        }
    }

	protected function installSinglePages($pkg)
	{
		$singlePages = [
			[
				'path'  => sprintf('/dashboard/system/permissions/%s', 'disable_copy'),
				'cName' => t('Disable site copy'),
			]
		];
		foreach ($singlePages as $singlePage) {
			$singlePageObject = Page::getByPath($singlePage['path']);
			// Check if it exists, if not, add it
			if ($singlePageObject->isError() || (!is_object($singlePageObject))) {
				$sp = SinglePage::add($singlePage['path'], $pkg);
				unset($singlePage['path']);
				if (!empty($singlePage)) {
					// And make sure we update the page with the remaining values
					$sp->update($singlePage);
				}
			}
		}
	}
	
	public function on_start()
	{
        Events::addListener('on_page_view', function() {
            $js = 
            '<script>
            $(document).ready(function(){
                $("body").bind("cut copy",function(e) {
                    e.preventDefault();
                })
                .on("contextmenu",function(e){
                    return false;
                });
                ConcreteAlert.error({
                    title: "Copy disabled"
                });
            });
            </script>';
        
            $v = \View::getInstance();
            if (is_object($v)) {
                $config = $this->app->make('config');
                $disable_site_copy = $config->get('concrete.permissions.disable_copy');
                
                $page = Page::getCurrentPage();
                if ($page && is_object($page) && !$page->isError()) {
                    $isAdminArea = $page && $page->isAdminArea();
                    $isEditMode = $page && $page->isEditMode();
                    
                    $al = AssetList::getInstance();
                    if ($disable_site_copy && !$isAdminArea && !$isEditMode) {
                        $al->register('javascript', 'disable_copy', 'js/disable_copy.js', array(), 'ab_disable_copy');
                        $v->requireAsset('javascript', 'disable_copy');
                    }
                    else {
                        $dc = $page->getAttribute('disable_copy');
                        if (!$isEditMode && !empty($dc) && $dc) {
                            $al->register('javascript', 'disable_copy', 'js/disable_copy.js', array(), 'ab_disable_copy');
                            $v->requireAsset('javascript', 'disable_copy');
                        }
                    }
                }
            }
        });
	}

}
